@@ -16,8 +16,14 @@ var SchemeGroupVersion = schema.GroupVersion{
 
 func AddToScheme(scheme *runtime.Scheme) error {
 	scheme.AddKnownTypes(SchemeGroupVersion,
+		&AcornImageBuildInstance{},
+		&AcornImageBuildInstanceList{},
+		&BuilderInstance{},
+		&BuilderInstanceList{},
 		&AppInstance{},
-		&AppInstanceList{})
+		&AppInstanceList{},
+		&ImageInstance{},
+		&ImageInstanceList{})
 
 	// Add common types
 	scheme.AddKnownTypes(SchemeGroupVersion, &metav1.Status{})
