@@ -21,6 +21,8 @@ var (
 	MinSizeQuantity     = Quantity("5M")
 	DefaultSize         = MustParseResourceQuantity(DefaultSizeQuantity)
 	MinSize             = MustParseResourceQuantity(MinSizeQuantity)
+	DefaultVerbs        = []string{"get", "list", "watch", "update", "patch", "delete", "deletecollection", "create"}
+	ReadVerbs           = []string{"get", "list", "watch"}
 )
 
 type routeTarget struct {
@@ -435,6 +437,7 @@ type containerAliases struct {
 	Directories         map[string]VolumeMount `json:"directories,omitempty"`
 	DependsOn           Dependencies           `json:"dependsOn,omitempty"`
 	DependsOnUnderscore Dependencies           `json:"depends_on,omitempty"`
+	Memory              *int64                 `json:"mem,omitempty"`
 }
 
 func (c containerAliases) SetContainer(dst Container) Container {
@@ -465,6 +468,9 @@ func (c containerAliases) SetContainer(dst Container) Container {
 	if len(c.DependsOnUnderscore) > 0 {
 		dst.Dependencies = c.DependsOnUnderscore
 	}
+	if c.Memory != nil {
+		dst.Memory = c.Memory
+	}
 	return dst
 }
 
@@ -533,9 +539,35 @@ func (in *PolicyRule) UnmarshalJSON(data []byte) error {
 	resource, apiGroup, _ := strings.Cut(s, ".")
 	in.Resources = []string{resource}
 	in.APIGroups = []string{apiGroup}
-	in.Verbs = []string{"*"}
+	in.Verbs = DefaultVerbs
 	if read {
-		in.Verbs = []string{"get", "list", "watch"}
+		in.Verbs = ReadVerbs
+	}
+
+	return nil
+}
+
+func (in *ClusterPolicyRule) UnmarshalJSON(data []byte) error {
+	if !isString(data) {
+		type clusterPolicyRule ClusterPolicyRule
+		return json.Unmarshal(data, (*clusterPolicyRule)(in))
+	}
+
+	s, err := parseString(data)
+	if err != nil {
+		return err
+	}
+	read := strings.HasPrefix(s, "read ")
+	if read {
+		s = strings.TrimPrefix(s, "read ")
+	}
+
+	resource, apiGroup, _ := strings.Cut(s, ".")
+	in.Resources = []string{resource}
+	in.APIGroups = []string{apiGroup}
+	in.Verbs = DefaultVerbs
+	if read {
+		in.Verbs = ReadVerbs
 	}
 
 	return nil
