@@ -1470,7 +1470,7 @@ images: image: image: "test"
 	assert.Equal(t, "side-hash", appSpec.Containers["foo"].Sidecars["side"].Image)
 	assert.Equal(t, "test", appSpec.Containers["foo"].Sidecars["side"].Build.BaseImage)
 	assert.Equal(t, "bar-hash", appSpec.Containers["bar"].Image)
-	assert.Equal(t, "test", appSpec.Containers["bar"].Build.BaseImage)
+	assert.Equal(t, "bar-hash", appSpec.Containers["bar"].Build.BaseImage)
 	assert.Equal(t, "job-hash", appSpec.Jobs["job"].Image)
 	assert.Equal(t, "test", appSpec.Jobs["job"].Build.BaseImage)
 	assert.Equal(t, "image-hash", appSpec.Images["image"].Image)
@@ -1790,6 +1790,7 @@ localData: permissions: {
       resources: ["resources"]
       resourceNames: ["names"]
       nonResourceURLs: ["foo"]
+	  namespaces: ["a", "b"]
     }
   ]
 }
@@ -1820,6 +1821,8 @@ containers: cont: {
 	assert.Equal(t, "groups", appSpec.Containers["cont"].Permissions.ClusterRules[0].APIGroups[0])
 	assert.Equal(t, "resources", appSpec.Containers["cont"].Permissions.ClusterRules[0].Resources[0])
 	assert.Equal(t, "names", appSpec.Containers["cont"].Permissions.ClusterRules[0].ResourceNames[0])
+	assert.Equal(t, "a", appSpec.Containers["cont"].Permissions.ClusterRules[0].Namespaces[0])
+	assert.Equal(t, "b", appSpec.Containers["cont"].Permissions.ClusterRules[0].Namespaces[1])
 	assert.Equal(t, "foo", appSpec.Containers["cont"].Permissions.ClusterRules[0].NonResourceURLs[0])
 
 	assert.Equal(t, "verb", appSpec.Containers["cont"].Sidecars["side"].Permissions.Rules[0].Verbs[0])
@@ -1832,6 +1835,8 @@ containers: cont: {
 	assert.Equal(t, "groups", appSpec.Containers["cont"].Sidecars["side"].Permissions.ClusterRules[0].APIGroups[0])
 	assert.Equal(t, "resources", appSpec.Containers["cont"].Sidecars["side"].Permissions.ClusterRules[0].Resources[0])
 	assert.Equal(t, "names", appSpec.Containers["cont"].Sidecars["side"].Permissions.ClusterRules[0].ResourceNames[0])
+	assert.Equal(t, "a", appSpec.Containers["cont"].Sidecars["side"].Permissions.ClusterRules[0].Namespaces[0])
+	assert.Equal(t, "b", appSpec.Containers["cont"].Sidecars["side"].Permissions.ClusterRules[0].Namespaces[1])
 	assert.Equal(t, "foo", appSpec.Containers["cont"].Sidecars["side"].Permissions.ClusterRules[0].NonResourceURLs[0])
 }
 
@@ -1999,7 +2004,8 @@ profiles: {
 func TestProfileDefaultValues(t *testing.T) {
 	data := `
 containers: default: files: a: std.toJSON(args)
-profiles: test: {
+// include some non-alpha characters
+profiles: "foo - bar": {
 	a: "b"
 }
 `
@@ -2008,14 +2014,14 @@ profiles: test: {
 		t.Fatal(err)
 	}
 
-	defaultAppDef, args, err := appDef.WithArgs(nil, []string{"test"})
+	defaultAppDef, args, err := appDef.WithArgs(nil, []string{"foo - bar"})
 	if err != nil {
 		t.Fatal(err)
 	}
 	assert.Equal(t, map[string]any{"a": "b"}, args)
 	assert.Equal(t, map[string]any{"a": "b", "dev": false}, getVals(t, defaultAppDef))
 
-	appDef, args, err = appDef.WithArgs(map[string]any{"a": "c", "c": "d"}, []string{"test"})
+	appDef, args, err = appDef.WithArgs(map[string]any{"a": "c", "c": "d"}, []string{"foo - bar"})
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -2197,7 +2203,7 @@ containers: test: {
 
 	assert.Equal(t, "pods", appSpec.Containers["test"].Permissions.Rules[0].Resources[0])
 	assert.Equal(t, "api.group", appSpec.Containers["test"].Permissions.Rules[0].APIGroups[0])
-	assert.Equal(t, "*", appSpec.Containers["test"].Permissions.Rules[0].Verbs[0])
+	assert.Equal(t, v1.DefaultVerbs, appSpec.Containers["test"].Permissions.Rules[0].Verbs)
 	assert.Equal(t, "secrets", appSpec.Containers["test"].Permissions.Rules[1].Resources[0])
 	assert.Equal(t, "", appSpec.Containers["test"].Permissions.Rules[1].APIGroups[0])
 	assert.Equal(t, []string{"get", "list", "watch"}, appSpec.Containers["test"].Permissions.Rules[1].Verbs)
