@@ -10,8 +10,8 @@ var (
 	apiServer = server.New()
 )
 
-func NewApiServer() *cobra.Command {
-	api := &APIServer{}
+func NewApiServer(c CommandContext) *cobra.Command {
+	api := &APIServer{client: c.ClientFactory}
 	cmd := cli.Command(api, cobra.Command{
 		Use:          "api-server [flags] [APP_NAME...]",
 		SilenceUsage: true,
@@ -23,7 +23,7 @@ func NewApiServer() *cobra.Command {
 }
 
 type APIServer struct {
-	DSN string `usage:"DB DSN" env:"DB_DSN"`
+	client ClientFactory
 }
 
 func (a *APIServer) Run(cmd *cobra.Command, args []string) error {
@@ -31,7 +31,6 @@ func (a *APIServer) Run(cmd *cobra.Command, args []string) error {
 	if err != nil {
 		return err
 	}
-	cfg.DSN = a.DSN
 
 	return apiServer.Run(cmd.Context(), cfg)
 }
