@@ -3,21 +3,20 @@ package cli
 import (
 	cli "github.com/acorn-io/acorn/pkg/cli/builder"
 	"github.com/acorn-io/acorn/pkg/cli/builder/table"
-	"github.com/acorn-io/acorn/pkg/client"
-	"github.com/acorn-io/acorn/pkg/system"
 	"github.com/acorn-io/acorn/pkg/tables"
 	"github.com/spf13/cobra"
 	"k8s.io/utils/strings/slices"
 )
 
-func NewApp() *cobra.Command {
-	return cli.Command(&App{}, cobra.Command{
+func NewApp(c CommandContext) *cobra.Command {
+	return cli.Command(&App{client: c.ClientFactory}, cobra.Command{
 		Use:     "app [flags] [APP_NAME...]",
 		Aliases: []string{"apps", "a", "ps"},
 		Example: `
 acorn app`,
-		SilenceUsage: true,
-		Short:        "List or get apps",
+		SilenceUsage:      true,
+		Short:             "List or get apps",
+		ValidArgsFunction: newCompletion(c.ClientFactory, appsCompletion).complete,
 	})
 }
 
@@ -25,18 +24,19 @@ type App struct {
 	All    bool   `usage:"Include stopped apps" short:"a"`
 	Quiet  bool   `usage:"Output only names" short:"q"`
 	Output string `usage:"Output format (json, yaml, {{gotemplate}})" short:"o"`
+	client ClientFactory
 }
 
 func (a *App) Run(cmd *cobra.Command, args []string) error {
-	client, err := client.Default()
+	c, err := a.client.CreateDefault()
 	if err != nil {
 		return err
 	}
 
-	out := table.NewWriter(tables.App, system.UserNamespace(), a.Quiet, a.Output)
+	out := table.NewWriter(tables.App, a.Quiet, a.Output)
 
 	if len(args) == 1 {
-		app, err := client.AppGet(cmd.Context(), args[0])
+		app, err := c.AppGet(cmd.Context(), args[0])
 		if err != nil {
 			return err
 		}
@@ -44,7 +44,7 @@ func (a *App) Run(cmd *cobra.Command, args []string) error {
 		return out.Err()
 	}
 
-	apps, err := client.AppList(cmd.Context())
+	apps, err := c.AppList(cmd.Context())
 	if err != nil {
 		return err
 	}
