@@ -3,41 +3,41 @@ package cli
 import (
 	cli "github.com/acorn-io/acorn/pkg/cli/builder"
 	"github.com/acorn-io/acorn/pkg/cli/builder/table"
-	"github.com/acorn-io/acorn/pkg/client"
-	"github.com/acorn-io/acorn/pkg/system"
 	"github.com/acorn-io/acorn/pkg/tables"
 	"github.com/spf13/cobra"
 	"k8s.io/utils/strings/slices"
 )
 
-func NewVolume() *cobra.Command {
-	cmd := cli.Command(&Volume{}, cobra.Command{
+func NewVolume(c CommandContext) *cobra.Command {
+	cmd := cli.Command(&Volume{client: c.ClientFactory}, cobra.Command{
 		Use:     "volume [flags] [VOLUME_NAME...]",
 		Aliases: []string{"volumes", "v"},
 		Example: `
 acorn volume`,
-		SilenceUsage: true,
-		Short:        "Manage volumes",
+		SilenceUsage:      true,
+		Short:             "Manage volumes",
+		ValidArgsFunction: newCompletion(c.ClientFactory, volumesCompletion).complete,
 	})
-	cmd.AddCommand(NewVolumeDelete())
+	cmd.AddCommand(NewVolumeDelete(c))
 	return cmd
 }
 
 type Volume struct {
 	Quiet  bool   `usage:"Output only names" short:"q"`
 	Output string `usage:"Output format (json, yaml, {{gotemplate}})" short:"o"`
+	client ClientFactory
 }
 
 func (a *Volume) Run(cmd *cobra.Command, args []string) error {
-	client, err := client.Default()
+	c, err := a.client.CreateDefault()
 	if err != nil {
 		return err
 	}
 
-	out := table.NewWriter(tables.Volume, system.UserNamespace(), a.Quiet, a.Output)
+	out := table.NewWriter(tables.Volume, a.Quiet, a.Output)
 
 	if len(args) == 1 {
-		volume, err := client.VolumeGet(cmd.Context(), args[0])
+		volume, err := c.VolumeGet(cmd.Context(), args[0])
 		if err != nil {
 			return err
 		}
@@ -45,7 +45,7 @@ func (a *Volume) Run(cmd *cobra.Command, args []string) error {
 		return out.Err()
 	}
 
-	volumes, err := client.VolumeList(cmd.Context())
+	volumes, err := c.VolumeList(cmd.Context())
 	if err != nil {
 		return err
 	}
