@@ -3,7 +3,6 @@ package config
 import (
 	"context"
 	"encoding/json"
-	"fmt"
 	"strings"
 
 	apiv1 "github.com/acorn-io/acorn/pkg/apis/api.acorn.io/v1"
@@ -64,14 +63,6 @@ func complete(ctx context.Context, c *apiv1.Config, getter kclient.Reader) error
 	if c.LetsEncryptTOSAgree == nil {
 		c.LetsEncryptTOSAgree = new(bool)
 	}
-	if *c.LetsEncrypt == "enabled" {
-		if c.LetsEncryptEmail == "" {
-			return fmt.Errorf("letsencrypt email is required when Let's Encrypt is enabled")
-		}
-		if !*c.LetsEncryptTOSAgree {
-			return fmt.Errorf("letsencrypt TOS must be agreed to when Let's Encrypt is enabled")
-		}
-	}
 	if c.AutoUpgradeInterval == nil || *c.AutoUpgradeInterval == "" {
 		c.AutoUpgradeInterval = &DefaultImageCheckIntervalDefault
 	}
@@ -139,7 +130,7 @@ func setClusterDomains(ctx context.Context, c *apiv1.Config, getter kclient.Read
 	}
 
 	// Acorn DNS should be used if it is explicitly "enabled" or if it is in "auto" mode and the user hasn't set a
-	//cluster domain and the cluster doesn't qualify for using the localhost wildcard domain
+	// cluster domain and the cluster doesn't qualify for using the localhost wildcard domain
 	if shouldLookupAcornDNSDomain {
 		dnsSecret := &corev1.Secret{}
 		err = getter.Get(ctx, router.Key(system.Namespace, system.DNSSecretName), dnsSecret)
@@ -220,6 +211,12 @@ func merge(oldConfig, newConfig *apiv1.Config) *apiv1.Config {
 	if newConfig.IgnoreUserLabelsAndAnnotations != nil {
 		mergedConfig.IgnoreUserLabelsAndAnnotations = newConfig.IgnoreUserLabelsAndAnnotations
 	}
+	if newConfig.AllowUserAnnotations != nil {
+		mergedConfig.AllowUserAnnotations = newConfig.AllowUserAnnotations
+	}
+	if newConfig.AllowUserLabels != nil {
+		mergedConfig.AllowUserLabels = newConfig.AllowUserLabels
+	}
 	if newConfig.IngressClassName != nil {
 		if *newConfig.IngressClassName == "" {
 			mergedConfig.IngressClassName = nil
@@ -227,7 +224,7 @@ func merge(oldConfig, newConfig *apiv1.Config) *apiv1.Config {
 			mergedConfig.IngressClassName = newConfig.IngressClassName
 		}
 	}
-	if newConfig.SetPodSecurityEnforceProfile == nil {
+	if newConfig.SetPodSecurityEnforceProfile != nil {
 		mergedConfig.SetPodSecurityEnforceProfile = newConfig.SetPodSecurityEnforceProfile
 	}
 	if newConfig.PodSecurityEnforceProfile != "" {
@@ -293,6 +290,14 @@ func merge(oldConfig, newConfig *apiv1.Config) *apiv1.Config {
 		mergedConfig.UseCustomCABundle = newConfig.UseCustomCABundle
 	}
 
+	if newConfig.PropagateProjectAnnotations != nil {
+		mergedConfig.PropagateProjectAnnotations = newConfig.PropagateProjectAnnotations
+	}
+
+	if newConfig.PropagateProjectLabels != nil {
+		mergedConfig.PropagateProjectLabels = newConfig.PropagateProjectLabels
+	}
+
 	return &mergedConfig
 }
 
