@@ -9,7 +9,6 @@ import (
 	"path"
 	"strings"
 
-	apiv1 "github.com/acorn-io/acorn/pkg/apis/api.acorn.io/v1"
 	v1 "github.com/acorn-io/acorn/pkg/apis/internal.acorn.io/v1"
 	"github.com/acorn-io/acorn/pkg/condition"
 	"github.com/acorn-io/acorn/pkg/config"
@@ -32,7 +31,7 @@ import (
 	kclient "sigs.k8s.io/controller-runtime/pkg/client"
 )
 
-func RemoveLabelsAndAnnotationsConfig(h router.Handler) router.Handler {
+func FilterLabelsAndAnnotationsConfig(h router.Handler) router.Handler {
 	return router.HandlerFunc(func(req router.Request, resp router.Response) error {
 		appInstance := req.Object.(*v1.AppInstance)
 		cfg, err := config.Get(req.Ctx, req.Client)
@@ -43,7 +42,7 @@ func RemoveLabelsAndAnnotationsConfig(h router.Handler) router.Handler {
 		// Note that IgnoreUserLabelsAndAnnotations will not be nil here because
 		// config.Get "completes" the config object to fill in default values.
 		if *cfg.IgnoreUserLabelsAndAnnotations {
-			req.Object = labels.RemoveUserDefined(appInstance)
+			req.Object = labels.FilterUserDefined(appInstance, cfg.AllowUserLabels, cfg.AllowUserAnnotations)
 		}
 
 		return h.Handle(req, resp)
@@ -72,12 +71,6 @@ func DeploySpec(req router.Request, resp router.Response) (err error) {
 		return err
 	}
 
-	cfg, err := config.Get(req.Ctx, req.Client)
-	if err != nil {
-		return err
-	}
-
-	addNamespace(cfg, appInstance, resp)
 	if err := addDeployments(req, appInstance, tag, pullSecrets, resp); err != nil {
 		return err
 	}
@@ -700,29 +693,6 @@ func ToDeployments(req router.Request, appInstance *v1.AppInstance, tag name.Ref
 	return result, nil
 }
 
-func addNamespace(cfg *apiv1.Config, appInstance *v1.AppInstance, resp router.Response) {
-	labelMap := map[string]string{
-		labels.AcornAppName:      appInstance.Name,
-		labels.AcornAppNamespace: appInstance.Namespace,
-		labels.AcornManaged:      "true",
-	}
-
-	labelMap = labels.Merge(labelMap, labels.GatherScoped("", "", appInstance.Status.AppSpec.Labels, nil, appInstance.Spec.Labels))
-	annotations := labels.GatherScoped("", "", appInstance.Status.AppSpec.Annotations, nil, appInstance.Spec.Annotations)
-
-	if *cfg.SetPodSecurityEnforceProfile {
-		labelMap["pod-security.kubernetes.io/enforce"] = cfg.PodSecurityEnforceProfile
-	}
-
-	resp.Objects(&corev1.Namespace{
-		ObjectMeta: metav1.ObjectMeta{
-			Name:        appInstance.Status.Namespace,
-			Labels:      labelMap,
-			Annotations: annotations,
-		},
-	})
-}
-
 func addFileContent(configMap *corev1.ConfigMap, appName, deploymentName string, container v1.Container) error {
 	data := configMap.BinaryData
 	for filePath, file := range container.Files {
