@@ -22,7 +22,7 @@ func ParseAppImage(req router.Request, resp router.Response) error {
 		return nil
 	}
 
-	appDef, _, err = appDef.WithArgs(appInstance.Spec.DeployArgs, appInstance.Spec.Profiles)
+	appDef, _, err = appDef.WithArgs(appInstance.Spec.DeployArgs, appInstance.Spec.GetProfiles())
 	if err != nil {
 		status.Error(err)
 		return nil
