@@ -1,14 +1,18 @@
 package system
 
-import "os"
-
 const (
 	Namespace            = "acorn-system"
+	ImagesNamespace      = "acorn-image-system"
 	ConfigName           = "acorn-config"
 	TLSSecretName        = "acorn-tls"
 	LEAccountSecretName  = "acorn-le-account"
 	DefaultUserNamespace = "acorn"
 	DNSSecretName        = "acorn-dns"
+
+	CustomCABundleSecretName = "cabundle"
+	CustomCABundleSecretVolumeName
+	CustomCABundleDir      = "/etc/ssl/certs"
+	CustomCABundleCertName = "ca-certificates.crt"
 )
 
 var (
@@ -18,25 +22,6 @@ var (
 	ControllerName           = "acorn-controller"
 	APIServerName            = "acorn-api"
 	BuildkitPort             = 8080
-	IndexURL                 = "https://cdn.acrn.io/ui/latest/index.html"
 	ContainerdConfigPathName = "containerd-config-path"
+	DefaultHubAddress        = "acorn.io"
 )
-
-func UserNamespace() string {
-	if os.Getenv("NAMESPACE_ALL") == "true" {
-		return ""
-	}
-	ns := os.Getenv("NAMESPACE")
-	if ns != "" {
-		return ns
-	}
-	return DefaultUserNamespace
-}
-
-func RequireUserNamespace() string {
-	ns := os.Getenv("NAMESPACE")
-	if ns != "" {
-		return ns
-	}
-	return DefaultUserNamespace
-}
